$set 14 #main

$ #RCRequiresArg
# napaka: '-rc' zahteva argument\n
$ #MENURequiresArg
# napaka: '-menu' zahteva argument\n
$ #DISPLAYRequiresArg
# napaka: '-display' zahteva argument\n
$ #WarnDisplaySet
# opozorilo: spremenljivke okolja 'DISPLAY' ni mo nastaviti\n
$ #Usage
# Openbox %s: (c) 2002 - 2002 Ben Jansens\n\
  \t\t\t  2001 - 2002 Sean 'Shaleh' Perry\n\
  \t\t\t  1997 - 2000 Brad Hughes\n\n\
  -display <string>\t\tuporabi prikazovalnik.\n\
  -rc <string>\t\t\tuporabi nadomestno datoteko z viri.\n\
  -menu <string>\t\t\tuse alternate menu file.\n\
  -version\t\t\tprikai oznako razliice in konaj.\n\
  -help\t\t\t\prikai ta navodila in konaj.\n\n
$ #CompileOptions
# Izbire pri prevajanju:\n\
  Razhroevanje\t\t\t%s\n\
  Prepletanje:\t\t\t%s\n\
  Oblika:\t\t\t%s\n\
  Rea:\t\t\t\t%s\n\
  Osembitno stresanje barv:\t%s\n\
  Event Clobbering:\t\t%s\n\n
